=========
Tutorials
=========

.. toctree::

   tutorial_profile_ordinal
   tutorial_profile_twelve
   tutorial_profile_histogram
   tutorial_profile_discrete
   tutorial_plurality_anti_plurality
   tutorial_tau_vector
   tutorial_mass_simulations
   tutorial_asymptotic_developments
